/*********************************************************************          
 *         Licensed Materials - Program Property of IBM.             *          
 *         This product contains "Restricted Materials of IBM"       *          
 *         5647-A01 (C) Copyright IBM Corp. 1992, 1997.              *          
 *         All rights reserved.                                      *          
 *         US Government Users Restricted Rights -                   *          
 *         Use, duplication or disclosure restricted                 *          
 *         by GSA ADP Schedule Contract with IBM Corp.               *          
 *         Refer to Copyright Instructions Form Number G120-2083.    *          
 *********************************************************************/         
                                                                                
/*------------------------ cbsamplm.c --------------------------------*         
 |  This is part of cbsample for CS/390 V2R5 or later.                |         
 |  This module provides the interface to monitor the MVS TCPIP.      |         
 |  It is intended to be linked with the module, cbsamplc.c which     |         
 |  provides the communications with the client, cbsample, running on |         
 |  the workstation.                                                  |         
 *--------------------------------------------------------------------*/        
                                                                                
#pragma csect(CODE,   "$CBSAMPM")                                               
#pragma csect(STATIC, "#CBSAMPM")                                               
                                                                                
#define OpenMonConnection  OpenMonC                                             
#define CloseMonConnection CloseMon                                             
                                                                                
#include <manifest.h>                                                           
#include <types.h>                                                              
#include <string.h>                                                             
#include <ioctl.h>                                                              
#include <errno.h>                                                              
#include <socket.h>                                                             
#include <ezbzmonc.h>                                                           
#include <cbsamplh.h>                                                           
                                                                                
MonDataIn   MonDataInBuf;                                                       
MonDataOut  MonDataOutBuf;                                                      
int  connopen = 0;                                                              
int  io_sock;                                                                   
extern int  debug;                                                              
extern char msgp;                                                               
                                                                                
/*========================*                                                     
 | --CloseMonConnection() |                                                     
 *========================*/                                                    
                                                                                
void CloseMonConnection()                                                       
{                                                                               
  int rc=0;                                                                     
                                                                                
  rc= close(io_sock);                                                           
  if(!rc) {                                                                     
     printf("Monitor connection closed, socket = %d\n", io_sock);               
    }                                                                           
  else {                                                                        
     printf("close() failed, return code = %d\n", rc);                          
     printf("errno - %d %s errno2 = %08x\n\n",                                  
             errno,strerror(errno),__errno2());                                 
    }                                                                           
  connopen = 0;                                                                 
}                                                                               
                                                                                
/*=======================*                                                      
 | --OpenMonConnection() |                                                      
 *=======================*/                                                     
                                                                                
void OpenMonConnection()                                                        
{                                                                               
  if ((io_sock = socket(AF_INET, SOCK_STREAM, 0)) >= 0) {                       
     printf("Monitor connection opened, socket = %d\n", io_sock);               
    }                                                                           
  else {                                                                        
     printf("socket() call failed, return code = %d\n", io_sock);               
     printf("errno - %d %s errno2 = %08x\n\n",                                  
             errno,strerror(errno),__errno2());                                 
    }                                                                           
  connopen = 1;                                                                 
}                                                                               
                                                                                
/*===================*                                                          
 | --ReadMibRecord() |                                                          
 *===================*/                                                         
                                                                                
void ReadMibRecord(MibResponse, pMibResponseLength)                             
char *MibResponse;                                                              
int  *pMibResponseLength;                                                       
{                                                                               
  int         rc=0;                                                             
                                                                                
  MonDataInBuf.BufVer  = MonDataVersion;                                        
  MonDataInBuf.BufLen  = sizeof(MonDataOut);                                    
  MonDataInBuf.BufAddr = &MonDataOutBuf;                                        
                                                                                
  rc = ioctl(io_sock,                                                           
             (unsigned long) SIOCGMONDATA,                                      
             (unsigned char *)&MonDataInBuf);                                   
  if(rc < 0) {                                                                  
    printf("%s SIOCGMONDATA call failed, return code = %d\n", rc);              
    printf("errno - %d %s errno2 = %08x\n\n",                                   
            errno,strerror(errno),__errno2());                                  
    *pMibResponseLength = 0;                                                    
  }                                                                             
  else {                                                                        
    /* Convert Octet counts to kilobytes (KBS)           */                     
    MonDataOutBuf.ioInOctets    >>= 10;                                         
    MonDataOutBuf.ioHCInOctets  <<= 22;                                         
    MonDataOutBuf.ioInOctets     &= MonDataOutBuf.ioHCInOctets;                 
    MonDataOutBuf.ioOutOctets   >>= 10;                                         
    MonDataOutBuf.ioHCOutOctets <<= 22;                                         
    MonDataOutBuf.ioOutOctets    &= MonDataOutBuf.ioHCOutOctets;                
    /* End Convert Octet counts to kilobytes (KBS)       */                     
                                                                                
    if (debug >= 4)                                                             
      {                                                                         
     printf("%s SIOCGMONDATA call successful:    \n",msgp);                     
     printf(" ipInReceives    = %i \n",MonDataOutBuf.ipInReceives   );          
     printf(" ipOutRequests   = %i \n",MonDataOutBuf.ipOutRequests  );          
     printf(" ipForwDatagrams = %i \n",MonDataOutBuf.ipForwDatagrams);          
     printf(" ipFragOKs       = %i \n",MonDataOutBuf.ipFragOKs      );          
     printf(" ipReasmOKs      = %i \n",MonDataOutBuf.ipReasmOKs     );          
     printf(" ipInAddrErrors  = %i \n",MonDataOutBuf.ipInAddrErrors );          
     printf(" ipInHdrErrors   = %i \n",MonDataOutBuf.ipInHdrErrors  );          
     printf(" ipFragCreates   = %i \n",MonDataOutBuf.ipFragCreates  );          
     printf(" ipFragFails     = %i \n",MonDataOutBuf.ipFragFails    );          
     printf(" ipReasmReqds    = %i \n",MonDataOutBuf.ipReasmReqds   );          
     printf(" ipReasmFails    = %i \n",MonDataOutBuf.ipReasmFails   );          
     printf(" icmpInMsgs      = %i \n",MonDataOutBuf.icmpInMsgs     );          
     printf(" icmpOutMsgs     = %i \n",MonDataOutBuf.icmpOutMsgs    );          
     printf(" tcpInSegs       = %i \n",MonDataOutBuf.tcpInSegs      );          
     printf(" tcpOutSegs      = %i \n",MonDataOutBuf.tcpOutSegs     );          
     printf(" tcpRetransSegs  = %i \n",MonDataOutBuf.tcpRetransSegs );          
     printf(" udpInDatagrams  = %i \n",MonDataOutBuf.udpInDatagrams );          
     printf(" udpOutDatagrams = %i \n",MonDataOutBuf.udpOutDatagrams);          
     printf(" arpInRequests   = %i \n",MonDataOutBuf.arpInRequests  );          
     printf(" arpInReplies    = %i \n",MonDataOutBuf.arpInReplies   );          
     printf(" arpOutReplies   = %i \n",MonDataOutBuf.arpOutReplies  );          
     printf(" arpOutRequests  = %i \n",MonDataOutBuf.arpOutRequests );          
     printf(" ioReads         = %i \n",MonDataOutBuf.ioReads        );          
     printf(" ioWrites        = %i \n",MonDataOutBuf.ioWrites       );          
     printf("   ioHCInOctets    = %i \n",MonDataOutBuf.ioHCInOctets );          
     printf(" ioInOctets      = %i \n",MonDataOutBuf.ioInOctets     );          
     printf("   ioHCOutOctets   = %i \n",MonDataOutBuf.ioHCOutOctets);          
     printf(" ioOutOctets     = %i \n",MonDataOutBuf.ioOutOctets    );          
     printf(" csaTotAllocated = %i \n",MonDataOutBuf.csaTotAllocated);          
     printf(" csaTotInUse     = %i \n",MonDataOutBuf.csaTotInUse    );          
     printf(" TotCPUtime1     = %i \n",MonDataOutBuf.TotCPUtime1    );          
     printf("   TotCPUtime2     = %i \n",MonDataOutBuf.TotCPUtime2  );          
     printf(" tcpConnections  = %i \n",MonDataOutBuf.tcpConnections );          
      }                                                                         
    memcpy(MibResponse, &MonDataOutBuf, sizeof(MonDataOut));                    
    *pMibResponseLength = sizeof(MonDataOut);                                   
  }                                                                             
}                                                                               
                                                        /*e-@D103*/             
